Quantcast

Put Blood Boil back

Taracque [10-16-14 - 09:26]
Put Blood Boil back
Filename
DKCrutch.lua
diff --git a/DKCrutch.lua b/DKCrutch.lua
index 2d35cf8..10f1660 100755
--- a/DKCrutch.lua
+++ b/DKCrutch.lua
@@ -39,6 +39,7 @@ DKCrutch.SpellList = {
 	["Pillar of Frost"] = GetSpellInfo(51271),
 	["Frost Strike"] = GetSpellInfo(49143),
 	["Death Strike"] = GetSpellInfo(49998),
+	["Blood Boil"] = GetSpellInfo(50842),
 	["Soul Reaper"] = GetSpellInfo(130736),

 -- talent specifig
@@ -682,6 +683,14 @@ function DKCrutch:AdviseBloodAbility()
 		bpExpiration = 0
 	end

+	-- Refresh diseases with Blood Boil if available
+	cd = DKCrutch:GetSpellCooldownRemaining(DKCrutch.SpellList["Blood Boil"])
+	if (cd) and (cd<=0) and (IsUsableSpell(DKCrutch.SpellList["Outbreak"], "target") == 1) then
+		if ( ( (ffExpiration - GetTime()) <5) or ( (bpExpiration - GetTime()) < 5) ) and ( ( (ffExpiration - GetTime()) > 1) and ( (bpExpiration - GetTime()) > 1) ) then
+			return "Blood Boil"
+		end
+	end
+
 	-- 	outbreak if frost fever or blood plague less than 2 sec remaining
 	obcd = DKCrutch:GetSpellCooldownRemaining(DKCrutch.SpellList["Outbreak"])
 	if (obcd) and (obcd<=0) and (IsSpellInRange(DKCrutch.SpellList["Outbreak"], "target") == 1) then
@@ -1063,11 +1072,19 @@ function DKCrutch:AdviseUnholyAbility()
 		end
 	end

-	-- Festering Strike if (blood=2 or frost=2)
-	local fscd = DKCrutch:GetSpellCooldownRemaining(DKCrutch.SpellList["Festering Strike"])
-	if (fscd) and (fscd <= 1) and ( (DKCrutch.runesUp[1] == 2) or (DKCrutch.runesUp[3] == 2) ) then
-		return "Festering Strike"
-	end
+	-- Blood boil, if AoE
+	if (DKCrutch.person["foeCount"]>1) then
+		local fscd = DKCrutch:GetSpellCooldownRemaining(DKCrutch.SpellList["Blood Boil"])
+		if (fscd) and (fscd <= 1) then
+			return "Blood Boil"
+		end
+	else
+ 	-- Festering Strike if (blood=2 or frost=2)
+		local fscd = DKCrutch:GetSpellCooldownRemaining(DKCrutch.SpellList["Festering Strike"])
+		if (fscd) and (fscd <= 1) and ( (DKCrutch.runesUp[1] == 2) or (DKCrutch.runesUp[3] == 2) ) then
+			return "Festering Strike"
+		end
+ 	end

 	-- Death coil if Sudden Doom proc, or runic power > 90
 	local dccd = DKCrutch:GetSpellCooldownRemaining(DKCrutch.SpellList["Death Coil"])